@@ -1,6 +1,6 @@
 import os
 from copy import copy
-from ape_safe import ApeSafe, transaction_service
+from ape_safe import ApeSafe, transaction_service, multisends
 from brownie import accounts, network, chain, Contract
 from gnosis.safe.safe_tx import SafeTx
 from eth_abi import encode_abi
